[API Review]Clarify method that obtain a component name

Change JavaDoc in CarrierConfigManager.java. Clarify what format
string will be set and get from the key. Using ComponentName methods
to convert.

Bug: 118675660
Test: build success.
Change-Id: I47db5b665808ef7dbc9081e0112a04958497d6fd
diff --git a/telephony/java/android/telephony/CarrierConfigManager.java b/telephony/java/android/telephony/CarrierConfigManager.java
index 90c15ff..8b9e01d 100644
--- a/telephony/java/android/telephony/CarrierConfigManager.java
+++ b/telephony/java/android/telephony/CarrierConfigManager.java
@@ -25,6 +25,7 @@
 import android.annotation.SystemService;
 import android.annotation.TestApi;
 import android.annotation.UnsupportedAppUsage;
+import android.content.ComponentName;
 import android.content.Context;
 import android.os.PersistableBundle;
 import android.os.RemoteException;
@@ -1153,11 +1154,20 @@
      */
     public static final String KEY_CARRIER_NAME_STRING = "carrier_name_string";
 
     /**
      * The Component Name of a carrier-provided CallScreeningService implementation. Telecom will
      * bind to this CallScreeningService for ALL incoming calls and provide the carrier
      * CallScreeningService with the opportunity to allow or block calls.
      */
     public static final String KEY_CARRIER_CALL_SCREENING_APP_STRING = "call_screening_app";
 
     /**
@@ -1153,11 +1154,20 @@
     public static final String KEY_CARRIER_NAME_STRING = "carrier_name_string";
 
-    /**
-     * The Component Name of a carrier-provided CallScreeningService implementation. Telecom will
-     * bind to this CallScreeningService for ALL incoming calls and provide the carrier
-     * CallScreeningService with the opportunity to allow or block calls.
-     */
+ /**
+  * The Component Name of a carrier-provided CallScreeningService implementation. Telecom will
+  * bind to {@link android.telecom.CallScreeningService} for ALL incoming calls and provide
+  * the carrier
+  * CallScreeningService with the opportunity to allow or block calls.
+  * <p>
+  * The String includes the package name/the class name.
+  * Example:
+  * <item>com.android.carrier/com.android.carrier.callscreeningserviceimpl</item>
+  * <p>
+  * Using {@link ComponentName#flattenToString()} to convert a ComponentName object to String.
+  * Using {@link ComponentName#unflattenFromString(String)} to convert a String object to a
+  * ComponentName.
+  */
     public static final String KEY_CARRIER_CALL_SCREENING_APP_STRING = "call_screening_app";
 